==> SoilManageR_1.0.1.tar.gz: SoilManageR/R/Globals.R <==
#This file defines global Variables to reduce devtools::check() notes to ZERO

utils::globalVariables(c("Comment", "Crop", "SP", "SS", "SR", "SE",
                         "CN_input_amendments_LUT",
                         "C_input_crops_LUT",
                         "plant_cover_LUT",
                         "STIR_values_LUT",
                         "Operation",
                         "year",
                         "soil_cover_days",
                         "plant_cover_days",
                         "residue_cover_days",
                         "Depth",
                         "STIR_original",
                         "Speed",
                         "Surf_Disturbance",
                         "TILLAGE_TYPE_Modifier",
                         "C_content",
                         "Cc_product",
                         "Cc_residue",
                         "DMC",
                         "N_content",
                         "crop_product",
                         "crop_residue",
                         "device",
                         "CC_event",
                         "C_input_CC",
                         "C_input_cover_crop",
                         "C_input_crop",
                         "C_input_exudate",
                         "C_input_org",
                         "C_input_org_amendment",
                         "C_input_product",
                         "C_input_root",
                         "C_input_straw",
                         "Remove",
                         "category",
                         "combination",
                         "comments",
                         "crop",
                         "duration_CC",
                         "machine",
                         "operation",
                         "product",
                         "unit",
                         "value",
                         "N_input_org",
                         "N_input_min",
                         "Amendment",
                         "LSU",
                         "count",
                         "p_i",
                         "Depth_MAX",
                         "Depth_MIN",
                         "Depth_max",
                         "Depth_min",
                         "Max_depht_check",
                         "Min_depht_check",
                         "check_next_operation",
                         "crop_product.y",
                         "crop_product.x"
                         ))

==> SoilManageR_1.1.0.tar.gz: SoilManageR/R/Globals.R <==
#This file defines global Variables to reduce devtools::check() notes to ZERO

utils::globalVariables(c("Comment", "Crop", "SP", "SS", "SR", "SE",
                         "CN_input_amendments_LUT",
                         "C_input_crops_LUT",
                         "plant_cover_LUT",
                         "STIR_values_LUT",
                         "Operation",
                         "year",
                         "soil_cover_days",
                         "plant_cover_days",
                         "residue_cover_days",
                         "Depth",
                         "STIR_original",
                         "Speed",
                         "Surf_Disturbance",
                         "TILLAGE_TYPE_Modifier",
                         "C_content",
                         "Cc_product",
                         "Cc_residue",
                         "DMC",
                         "N_content",
                         "crop_product",
                         "crop_residue",
                         "device",
                         "CC_event",
                         "C_input_CC",
                         "C_input_cover_crop",
                         "C_input_crop",
                         "C_input_exudate",
                         "C_input_org",
                         "C_input_org_amendment",
                         "C_input_product",
                         "C_input_root",
                         "C_input_straw",
                         "Remove",
                         "category",
                         "combination",
                         "comments",
                         "crop",
                         "duration_CC",
                         "crop_cover",
                         "residue_cover",
                         "CC_cover",
                         "cover_crop_cover",
                         "machine",
                         "operation",
                         "product",
                         "unit",
                         "value",
                         "N_input_org",
                         "N_input_min",
                         "Amendment",
                         "LSU",
                         "count",
                         "p_i",
                         "Depth_MAX",
                         "Depth_MIN",
                         "Depth_max",
                         "Depth_min",
                         "Max_depht_check",
                         "Min_depht_check",
                         "check_next_operation",
                         "crop_product.y",
                         "crop_product.x",
                         "var_MGMT_data",
                         "crop_no",
                         "days",
                         "harvest",
                         "last",
                         "n",
                         "fungicide",
                         "insecticide",
                         "herbicide",
                         "days_since"
                         ))
